@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Moo;
 use strictures 2;
@@ -122,7 +122,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -233,11 +233,6 @@ Currently, this is constructed by selecting a B<pool> duration at
 random, that fits into the size remaining after each application, in a
 loop until the B<size> is met.
 
-=head1 TO DO
-
-Give ->motif a code reference to select a pool duration instead of "at
-random."
-
 =head1 SEE ALSO
 
 The F<t/01-methods.t>, F<eg/motif> and F<eg/shuffle> code in this
